@@ -131,10 +131,15 @@ export class Patient extends Model {
       foreignKey: 'patientId',
       as: 'contacts',
     });
+
+    this.hasOne(models.PortalUser, {
+      foreignKey: 'patientId',
+      as: 'portalUser',
+    });
   }
 
   static getFullReferenceAssociations() {
-    return ['markedForSyncFacilities', 'fieldValues'];
+    return ['markedForSyncFacilities', 'fieldValues', 'portalUser'];
   }
 
   async getAdministeredVaccines(
@@ -183,7 +188,7 @@ export class Patient extends Model {
       );
     }
 
-    if (!include.some((i) => i.as === 'scheduledVaccine')) {
+    if (!include.some(i => i.as === 'scheduledVaccine')) {
       include.push({
         model: models.ScheduledVaccine,
         as: 'scheduledVaccine',
@@ -204,7 +209,7 @@ export class Patient extends Model {
       },
     });
 
-    const data = rows.map((x) => x.get({ plain: true }));
+    const data = rows.map(x => x.get({ plain: true }));
 
     for (const record of data) {
       if (certifiableVaccineIds.includes(record.scheduledVaccine.vaccineId)) {
